@@ -434,8 +434,6 @@ class USERENUM:
 # Process command-line arguments.
 if __name__ == '__main__':
     print(version.BANNER)
-    # Init the example's logger theme
-    logger.init()
 
     parser = argparse.ArgumentParser()
 
@@ -453,6 +451,7 @@ if __name__ == '__main__':
                                                                        '(default 10 seconds)')
     parser.add_argument('-max-connections', action='store', default='1000', help='Max amount of connections to keep '
                                                                                  'opened (default 1000)')
+    parser.add_argument('-ts', action='store_true', help='Adds timestamp to every logging output')
     parser.add_argument('-debug', action='store_true', help='Turn DEBUG output ON')
 
     group = parser.add_argument_group('authentication')
@@ -473,8 +472,13 @@ if __name__ == '__main__':
 
     options = parser.parse_args()
 
+    # Init the example's logger theme
+    logger.init(options.ts)
+
     if options.debug is True:
         logging.getLogger().setLevel(logging.DEBUG)
+        # Print the Library's installation path
+        logging.debug(version.getInstallationPath())
     else:
         logging.getLogger().setLevel(logging.INFO)
 
